@@ -98,6 +98,7 @@ sub SplitterWindow {
    my $don = Wx::Bitmap->new("donate.png",
                          wxBITMAP_TYPE_PNG );
    my $dn=Wx::BitmapButton->new($banner,-1,$don,[12.7,12.7]);
+   $dn->SetToolTip( Wx::ToolTip->new( Wx::gettext('Please Donate!') ) );
    $dn->Enable(1);
 	
    my $rightWindows = Wx::SplitterWindow->new($splitterWindow, -1);
@@ -236,8 +237,10 @@ sub SplitterWindow {
    my $statbm = '';
    if($pem_file && $ip_txt) {
      $statbm = Wx::StaticBitmap->new($rightbottom,-1,$presshere,[440,30]);
+     $statbm->SetToolTip( Wx::ToolTip->new( Wx::gettext('Press FA =>') ) );
    } elsif ($saved_txt) {
      $statbm = Wx::StaticBitmap->new($rightbottom,-1,$presshere,[440,105]);
+     $statbm->SetToolTip( Wx::ToolTip->new( Wx::gettext('Press FA =>') ) );
    } else {
      $statbm = Wx::StaticBitmap->new($rightbottom,-1,$notready,[440,105]);
    }
@@ -411,6 +414,7 @@ sub SplitterWindow {
       $cbt=16;
    }
    my $cb=Wx::BitmapButton->new($rightbottom,-1,$clb,[30,$cbt]);
+   $cb->SetToolTip( Wx::ToolTip->new( Wx::gettext('CLIPBUCKET Setup Instructions') ) );
    $cb->Enable(1);
    my $gnu = Wx::Bitmap->new("gnusoc.png",
                          wxBITMAP_TYPE_PNG );
@@ -419,6 +423,7 @@ sub SplitterWindow {
       $gnt=16;
    }
    my $gs=Wx::BitmapButton->new($rightbottom,-1,$gnu,[30,$gnt]);
+   $gs->SetToolTip( Wx::ToolTip->new( Wx::gettext('GNU Social Setup Instructions') ) );
    $gs->Enable(1);
    $rightbottom->{bb}=$bb;
    $rightbottom->{bmp}=$bmp;
@@ -443,6 +448,7 @@ sub SplitterWindow {
    $rightbottom->{tagged} = $tagged if defined $tagged;
    EVT_BUTTON( $rightbottom, $bb, \&fullauto_button);
    EVT_BUTTON( $rightbottom, $cb, \&cb_button);
+   EVT_BUTTON( $banner, $dn, \&dn_button);
    EVT_BUTTON( $rightbottom, $gs, \&gs_button);
    EVT_DROP_FILES( $rightbottom, \&main::on_drop );
 
@@ -714,17 +720,27 @@ print "GOING TO RUNPUTTY: runputty \"$self->{ppk_file}\" $iptext\n";
 
 }
 
+sub dn_button {
+
+   my ($self, $event) =@_;
+   my $webapp_url='http://www.fullauto.com';
+   Wx::LaunchDefaultBrowser($webapp_url,wxBROWSER_NEW_WINDOW);
+
+}
+
 sub cb_button {
 
    my ($self, $event) =@_;
-   Wx::PdfDocument::LaunchPdfViewer('');
+   my $webapp_url='file:///FullAuto%20Windows%20Dashboard%20CLIPBUCKET%20Linux%20Installation%20Instructions.pdf';
+   Wx::LaunchDefaultBrowser($webapp_url,wxBROWSER_NEW_WINDOW);
 
 }
 
 sub gs_button {
 
    my ($self, $event) =@_;
-   Wx::PdfDocument::LaunchPdfViewer('');
+   my $webapp_url='file:///FullAuto%20Windows%20Dashboard%20GNU%20Social%20Installation%20Instructions.pdf';
+   Wx::LaunchDefaultBrowser($webapp_url,wxBROWSER_NEW_WINDOW);
 
 }
 
